@@ -1,5 +1,5 @@
 /*
- * version.c - Return the version of the blkid library
+ * version.c - Return the version of the libmount library
  *
  * Copyright (C) 2008 Karel Zak <kzak@redhat.com>
  * [Based on libblkid/version.c by Theodore Ts'o]
@@ -8,9 +8,9 @@
  */
 
 /**
- * SECTION: version
+ * SECTION: version-utils
  * @title: Version functions
- * @short_description: functions to get library version.
+ * @short_description: functions to get the library version.
  */
 
 #include <ctype.h>
@@ -22,9 +22,13 @@ static const char *lib_features[] = {
 #ifdef HAVE_LIBSELINUX
 	"selinux",
 #endif
-#ifdef CONFIG_LIBMOUNT_DEBUG
-	"debug",
+#ifdef HAVE_SMACK
+	"smack",
 #endif
+#if !defined(NDEBUG)
+	"assert",	/* libc assert.h stuff */
+#endif
+	"debug",	/* always enabled */
 	NULL
 };
 
@@ -39,6 +43,8 @@ int mnt_parse_version_string(const char *ver_string)
 	const char *cp;
 	int version = 0;
 
+	assert(ver_string);
+
 	for (cp = ver_string; *cp; cp++) {
 		if (*cp == '.')
 			continue;
@@ -65,11 +71,11 @@ int mnt_get_library_version(const char **ver_string)
 
 /**
  * mnt_get_library_features:
- * @features: returns pointer to the static array of strings, the array is
+ * @features: returns a pointer to the static array of strings, the array is
  *            terminated by NULL.
  *
  * Returns: number of items in the features array not including the last NULL,
- *          or less then zero in case of error
+ *          or less than zero in case of error
  *
  * Example:
  * <informalexample>
