@@ -51,8 +51,6 @@ extern int optind;
 #include "ttyutils.h"
 #include "xalloc.h"
 
-const char *progname = "blkid";
-
 int raw_chars;
 
 static void print_version(FILE *out)
@@ -98,7 +96,7 @@ static void usage(int error)
 		" -O <offset> probe at the given offset\n"
 		" -u <list>   filter by \"usage\" (e.g. -u filesystem,raid)\n"
 		" -n <list>   filter by filesystem type (e.g. -n vfat,ext3)\n"
-		"\n", progname);
+		"\n", program_invocation_short_name);
 
 	exit(error);
 }
@@ -106,8 +104,10 @@ static void usage(int error)
 /*
  * This function does "safe" printing.  It will convert non-printable
  * ASCII characters using '^' and M- notation.
+ *
+ * If 'esc' is defined then escape all chars from esc by \.
  */
-static void safe_print(const char *cp, int len)
+static void safe_print(const char *cp, int len, const char *esc)
 {
 	unsigned char	ch;
 
@@ -124,7 +124,9 @@ static void safe_print(const char *cp, int len)
 			if ((ch < 32) || (ch == 0x7f)) {
 				fputc('^', stdout);
 				ch ^= 0x40; /* ^@, ^A, ^B; ^? for DEL */
-			}
+
+			} else if (esc && strchr(esc, ch))
+				fputc('\\', stdout);
 		}
 		fputc(ch, stdout);
 	}
@@ -255,6 +257,9 @@ static void print_udev_format(const char *name, const char *value)
 		blkid_encode_string(value, enc, sizeof(enc));
 		printf("ID_FS_%s_ENC=%s\n", name, enc);
 
+	} else if (!strcmp(name, "PTUUID")) {
+		printf("ID_PART_TABLE_UUID=%s\n", value);
+
 	} else if (!strcmp(name, "PTTYPE")) {
 		printf("ID_PART_TABLE_TYPE=%s\n", value);
 
@@ -301,16 +306,17 @@ static void print_value(int output, int num, const char *devname,
 			printf("DEVNAME=%s\n", devname);
 		fputs(name, stdout);
 		fputs("=", stdout);
-		safe_print(value, valsz);
+		safe_print(value, valsz, " \\\"'$`<>");
 		fputs("\n", stdout);
 
 	} else {
 		if (num == 1 && devname)
-			printf("%s: ", devname);
+			printf("%s:", devname);
+		fputs(" ", stdout);
 		fputs(name, stdout);
 		fputs("=\"", stdout);
-		safe_print(value, valsz);
-		fputs("\" ", stdout);
+		safe_print(value, valsz, "\"\\");
+		fputs("\"", stdout);
 	}
 }
 
@@ -504,21 +510,6 @@ static int lowprobe_device(blkid_probe pr, const char *devname,
 	if (!rc)
 		nvals = blkid_probe_numof_values(pr);
 
-	if (nvals &&
-	    !(chain & LOWPROBE_TOPOLOGY) &&
-	    !(output & OUTPUT_UDEV_LIST) &&
-	    !blkid_probe_has_value(pr, "TYPE") &&
-	    !blkid_probe_has_value(pr, "PTTYPE"))
-		/*
-		 * Ignore probing result if there is not any filesystem or
-		 * partition table on the device and udev output is not
-		 * requested.
-		 *
-		 * The udev db stores information about partitions, so
-		 * PART_ENTRY_* values are alway important.
-		 */
-		nvals = 0;
-
 	if (nvals && !first && output & (OUTPUT_UDEV_LIST | OUTPUT_EXPORT_LIST))
 		/* add extra line between output from devices */
 		fputc('\n', stdout);
@@ -594,7 +585,7 @@ static int list_to_usage(const char *list, int *flag)
 	return mask;
 err:
 	*flag = 0;
-	fprintf(stderr, "unknown kerword in -u <list> argument: '%s'\n",
+	fprintf(stderr, "unknown keyword in -u <list> argument: '%s'\n",
 			word ? word : list);
 	exit(BLKID_EXIT_OTHER);
 }
